%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief Calculate the microDoppler specturm.               
% @param[in] rangeDoppler   - [M,numBins,numFrames] matrix  
% @param[in] rangeGates     - Start and end range bins                                  
%
% @param[out] microDoppler  - [M,numFrames] matrix            
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function microDoppler = getMicrodoppler(rangeDoppler,rangeGates)
    Output.INFO('Calculating micro doppler...\n');
    [M,~,numFrames] = size(rangeDoppler);
    microDoppler = zeros(M,numFrames);

    rL = rangeGates.rL;
    rH = rangeGates.rH;
    for frame = 1:numFrames
%             lowBin = rL(frame);
%             highBin = rH(frame);
        for m = 1:M
            microDoppler(m,frame) = sum(rangeDoppler(m,:,frame));
        end
        normfact = max(microDoppler(:,frame));
        microDoppler(:,frame) = microDoppler(:,frame)/normfact; % [Volt]

    end
    Output.INFO('Micro doppler finished.\n');
end


