%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief This function finds lower and upper range bins             
% @param[in] rangeDoppler       - Range doppler matrix
% @param[in] hdrMat             
% @param[in] radarSettings      - Struct containing radar settings
% @param[in] rangeVector
% @param[out] trackingLimits    - Start and end range bins 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function  trackingLimits = getRangeGate(rangeDoppler,hdrMat,radarSettings,rangeVector)
Output.INFO('Finding range gates...\n');

stftHop = radarSettings.stftHop;
rangeGate = radarSettings.rangeGate/2;

numBins = hdrMat(1,2); % numBins
binLength = hdrMat(1,3);

[~,~,numFrames] = size(rangeDoppler);

% get tracking limits
rL = zeros(numFrames,1);
rH = zeros(numFrames,1);

for frame = 1:stftHop:numFrames
    rL(frame) = max(round((rangeVector(frame) - rangeGate)/binLength),1); 
    rH(frame) = min(round((rangeVector(frame) + rangeGate)/binLength), numBins);
end

trackingLimits.rL = rL;
trackingLimits.rH = rH;   
Output.INFO('Range gates found.\n');
end

