clc; clear; close all;
cd('C:\Users\borgewi\Documents\master\');
addpath(genpath('C:\Users\borgewi\Documents\master\'));

recordingSettings;

radarSettings.year = '2017';
recordingName = 'Dog_0deg';

rawfile = strcat(recordingPath,radarSettings.year,'\',recordingName,'\');

startFrame = 51000;
endFrame = 52600;
%% Read rawfile
[hdrMat, frameMat] = readRawfile(rawfile);

hdr = hdrMat(1,:);
numBins = hdr(2);

%% Get baseband frames (IQ data)
BBframes = getBBframes(startFrame, endFrame, numBins, frameMat); 

%% Feature extracting
disp('Extracting features');
hdrMat = hdrMat(startFrame:endFrame,:);

[pulseDoppler,~,~] = getPulseDoppler(hdrMat, BBframes, radarSettings);

pulseDoppler_limited = limitPulseDoppler(pulseDoppler, radarSettings.pd_dB_limit);

rangeVector = getRangeVector(rawfile,startFrame, endFrame);
rangeGates = getRangeGate(pulseDoppler, hdrMat, radarSettings, rangeVector);

microDoppler = getMicrodoppler(pulseDoppler_limited,rangeGates);

%% Plot micro doppler
prf = radarSettings.prf;
dB_limit = radarSettings.md_dB_limit;
figMD = plotMicroDopplerImage(microDoppler, prf, dB_limit);

%% Save to folder
nameExtension = ['microDopppler_',radarSettings.year,'_',recordingName,'_frames',num2str(startFrame),'-',num2str(endFrame)];
filename = [radarSettings.outputFolder,nameExtension,'.mat'];
save(filename,'microDoppler','-v7.3');    

figName = [radarSettings.outputFolder,nameExtension];
formattype = 'epsc';
saveas(figMD,figName,formattype);
