% This script generates synthetic micro doppler data

clc; clear; close all;

makePlots             = 'n';
makeMovies            = 'n'; 
movieSettings = setAnimationSettings(100,'bird'); 

%% Simulator
[hdrMat,frames,rangeCellArray, prf, outputFolder, targetName, radarPosName, ~, ~] = simulatorWrapper(movieSettings,makePlots,makeMovies);
%% radarSettings
stftHop = 1;

simParam.winLen = 64;
simParam.prf = prf;
simParam.timeBetwUpd = stftHop/simParam.prf;
simParam.stftHop = max(ceil(simParam.timeBetwUpd*simParam.prf),1);
simParam.outputFolder = outputFolder;

%Range gating
simParam.rangeGate = 1;        %[m]
% Desibel limits 
simParam.pd_dB_limit = -100;
simParam.md_dB_limit = -30;

%% Feature Extraction
rangeVector = rangeCellArray{1,1};
[rangeDoppler, ~, ~] = getPulseDoppler(hdrMat,frames,simParam);
rangeGates = getRangeGate(rangeDoppler, hdrMat, simParam, rangeVector);
microDoppler = getMicrodoppler(rangeDoppler, rangeGates);

%% Plotting
dB_limit = simParam.md_dB_limit;
figMD = plotMicroDopplerImage(microDoppler, prf, dB_limit);

%% Save files
if ~exist(outputFolder,'dir')
    mkdir(outputFolder);
end

formattype = 'epsc';
figName = [outputFolder,'microDoppler_',targetName{1,1},'_',radarPosName];
saveas(figMD,figName,formattype);

filename = [outputFolder,'microDoppler_',targetName{1,1},'_',radarPosName,'.mat'];
save(filename,'microDoppler','-v7.3');    

Output.INFO('Run completed.\n');


