% @brief Plots micro doppler matrices and returns figure
%
% param[in] microDoppler - [nfft,numFrames] matrix
% param[in] prf          - Pulse Repetition Frequency 
% param[in] dB_limit     - desibel limit to increase color contrasts

% param[out] figMD       - Micro doppler figure

function figMD = plotMicroDopplerImage(microDoppler, prf, dB_limit)
    targetString = [];

    [nfft,numFrames] = size(microDoppler);
   
    microDoppler = max(microDoppler,0);     % Remove negative numbers that may appear from interpolation when using imresize
    microDoppler_dB = 10*log10(microDoppler);
    microDoppler_dB_limited = max(microDoppler_dB, dB_limit);
    
    dopplerAx = linspace(-prf/2,prf/2,nfft);
    timeAx = linspace(0,(1/prf)*numFrames,numFrames);

    figMD = figure('Name','micro-Doppler spectrum','NumberTitle','off');
    surf(timeAx,dopplerAx,(microDoppler_dB_limited),'LineStyle','none');
    title({'Time-frequency power spectrum'; targetString}); xlabel('Time [s]'); ylabel('Doppler frequency [Hz]');
    axis([0 (1/prf)*numFrames -prf/2 prf/2]);
    colormap('jet');
    cc = colorbar;
    ylabel(cc, 'Power [dB]');
    set(gca                                 , ...
        'FontName'          , 'Helvetica'   , ...
        'FontSize'          , 40            , ...
        'LineWidth'         , 3             , ...
        'YGrid'             , 'on'          );
    
    view(2);
end

