%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief Plots all micro doppler images in dataset
%
% param[in] microDoppler - [nfft,numFrames, numCh, numImages] matrix
% param[in] prf          - Pulse Repetition Frequency 
% param[in] dB_limit     - desibel limit to increase color contrasts
% param[in] pauseTime    - The time duration at which each image is plotted


function plotMicroDopplerVideo(microDoppler, prf, window, dB_limit, pauseTime)

    targetString = [];

    [nfft,numFrames,~,numImages] = size(microDoppler);
    microDoppler = max(microDoppler,0);     % Remove negative numbers that may appear from interpolation when using imresize
    
    microDoppler_dB = 10*log10(microDoppler);
    microDoppler_dB_limited = max(microDoppler_dB, dB_limit);    
    timeAx = linspace(0,(1/prf)*window,numFrames);
    dopplerAx = linspace(-prf/2,prf/2,nfft);

    for image = 1:numImages

        surf(timeAx,dopplerAx,(microDoppler_dB_limited(:,:,:,image)),'LineStyle','none');
        title({'Time-frequency power spectrum'; targetString}); xlabel('Time [s]'); ylabel('Doppler frequency [Hz]');
        
        colormap('jet');
        cc = colorbar;
        ylabel(cc, 'Power [dB]');
        colorLim = [-45 0];
        caxis(colorLim);
        view(2);

        pause(pauseTime)
    end
end
