%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief Obtains loss and accuracy from trainingInfo        
% @param[in] trainingInfo   - struct containing network info from training
% @param[in] iterations     - number of training iterations                                    
% @param[out] trainLoss     - training loss                                   
% @param[out] trainAcc      - training accuracy           
% @param[out] valLoss       - validation loss            
% @param[out] valAcc        - validation accuracy 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function [trainLoss,trainAcc, valLoss, valAcc] = getLossAndAccuracy(trainingInfo, iterations)
    trainLoss = trainingInfo.TrainingLoss;
    trainAcc = trainingInfo.TrainingAccuracy;
    
    %% Find NaN within validation data and interpolate
    valAccDiscrete = isfinite(trainingInfo.ValidationAccuracy);
    valAccWithoutNaN = trainingInfo.ValidationAccuracy(valAccDiscrete);
    valAccIdx = find(valAccDiscrete == 1);
    valAcc = interp1(valAccIdx, valAccWithoutNaN, iterations);
    
    valLossDiscrete = isfinite(trainingInfo.ValidationLoss);
    valLossWithoutNaN = trainingInfo.ValidationLoss(valLossDiscrete);
    valLossIdx = find(valLossDiscrete == 1);
    valLoss = interp1(valLossIdx, valLossWithoutNaN, iterations);
    
end

