%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief This function artificially expands the training data by rotation
%
% @param[in] X_Train        - Training data
% @param[in] T_Train        - Training data labels
% @param[in] dataSettings   - Struct with data parameters
% @param[out] X_Train_Exp   - Training data rotated
% @param[in]  T_Train_Exp   - Training data labels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [X_Train_Exp, T_Train_Exp] = imRotate(X_Train, T_Train, dataSettings)
    
    expFactor = dataSettings.expRotationFactor;
    angleInterval = dataSettings.angleInterval
    [nfft, numPD, numCh, numImages] = size(X_Train);
    % Artificial expansion of scalogram - like 2D images of radar signals .
    X_Train_Exp = zeros(nfft ,numPD , numCh ,numImages*expFactor);
    T_Train_Exp = categorical(NaN(1,numImages*expFactor));

    fprintf ('Art Exp sample :')
    for i=1:numImages
        originalX = X_Train(:,:,:,i);
        originalT = T_Train(i);
        % Periodically print progress
        if mod(i,100) ==0
            fprintf('%d ',i)
        end

        % Original
        X_Train_Exp(:,:,:,expFactor*(i-1)+1) = originalX;
        T_Train_Exp(expFactor*(i-1)+1) = originalT;
        
        % Rotate image expFactor-1 times
        for k = 1:(expFactor-1)
            angle = randi(angleInterval, 1, 1);
            X_Train_Exp(:,:,:,expFactor*(i-1)+k+1) = imrotate(originalX, angle, 'crop');
            T_Train_Exp(expFactor*(i-1)+k+1) = originalT;
        end

    end
    fprintf ('\n')        

end