%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief This function artificially expands the training data by vertical
% shift
%
% @param[in] X_Train        - Training data
% @param[in] T_Train        - Training data labels
% @param[in] dataSettings   - Struct with data parameters
% @param[out] X_Train_Exp   - Training data rotated
% @param[in]  T_Train_Exp   - Training data labels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [X_Train_Exp, T_Train_Exp] = imVerticalShift(X_Train, T_Train, dataSettings)
    
    expFactor = dataSettings.expFactor;
    % Artificial expansion of scalogram - like 2D images of radar signals .
    X_Train_Exp = zeros(size(X_Train, 1) ,size(X_Train, 2) , size(X_Train, 3) ,size(X_Train, 4)*expFactor);
    T_Train_Exp = categorical(NaN(1,size(T_Train,2)*expFactor));

    fprintf ('Art Exp sample :')
    for k=1:size(X_Train,4)
        x_train = X_Train(:,:,:,k);
        t_train = T_Train(k);

        % Periodically print progress
        if mod(k,100) ==0
            fprintf('%d ',k)
        end

        % Original
        X_Train_Exp(:,:,:,expFactor*(k-1)+1) = x_train ;
        T_Train_Exp(expFactor*(k -1)+1) = t_train ;

        % Shifted
        for m =1:(expFactor-1)
            X_Train_Exp(:,:,:,expFactor*(k-1)+m+1) = [x_train(2*m:end,:) ; x_train(1:2*m-1,:)];
            T_Train_Exp(expFactor*(k-1)+m+1)= t_train ;
        end
    end
    fprintf ('\n')        

end