%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief This function saves the hyperparameters to text file at specified path location
%
% @param[in] savePath       - Path location
% @param[in] hp             - Struct containing hyperparameters
% @param[in] layers          - Struct with network layers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function saveHyperparameters(savePath,hp, layers)

Output.INFO('Saving hyperparameters to text file...\n');

fileID = fopen(fullfile(savePath,'hyperparameters.txt'),'w');
fprintf(fileID, strcat( ... 
    '\r\nHyperparameters: \r\n'                                                 , ... 
    '\r\nMini-Batch Size: '                 , num2str(hp.miniBatchSize)         , ...    
    '\r\nEpochs: '                          , num2str(hp.maxEpochs)             , ...    
    '\r\nInitial Learning Rate: '           , num2str(hp.initLearnRate)         , ...
    '\r\nLearning Rate Drop Factor: '       , num2str(hp.learnRateDropFactor)   , ...
    '\r\nLearning Rate Drop Period: '       , num2str(hp.learnRateDropPeriod)   , ...    
    '\r\nMomentum: '                        , num2str(hp.momentum)              , ...    
    '\r\nL2Regularization: '                , num2str(hp.L2regularization)      , ...        
    '\r\n',...
    '\r\nImage input Size: '                , num2str(hp.imageInputSize)        , ...        
    '\r\nFilter Size: '                     , num2str(hp.filterSize)            , ...    
    '\r\nPadding Size: '                    , num2str(hp.padding)               , ... 
    '\r\nStride Size: '                     , num2str(hp.stride)                , ...     
    '\r\nPooling Size: '                    , num2str(hp.pooling)               , ...        
    '\r\nShuffle: '                         , hp.shuffle                        , ...  
    '\r\n',...
    '\r\nTraining ratio: '                  , num2str(hp.trainRatio)            , ...
    '\r\nValidation ratio: '                , num2str(hp.valRatio)              , ...
    '\r\n',...    
    '\r\nFilter plotting iterations: '      , num2str(hp.numFilterIterations)   , ...
    '\r\nSeed: '                            , num2str(hp.seed)                  , '\r\n'));

% Print number of filters in the convolutional layers
for l = 1:size(layers,1)
    if contains(layers(l).Name,'Conv')
        fprintf(fileID, strcat( ... 
            '\r\nNumber of filters conv layer ', num2str(l), ': ', num2str(layers(l).NumFilters),'\r'));        
    else
        continue
    end
end
% Print number of elements in FC layers
fc_counter = 0;
for l = 1:size(layers,1)
    if contains(layers(l).Name,'Feedforward')
        fc_counter = fc_counter + 1;
        fprintf(fileID, strcat( ... 
            '\r\nNumber of elements in FC ', num2str(fc_counter), ': ', num2str(hp.fcHiddenSize(fc_counter)),'\r'));        
    else
        continue
    end
end
% Print number of elements in outputlayer  
fprintf(fileID, strcat('\r\nOutput size: ', num2str(hp.fcOutputSize),'\r\n'));    

% Check if dropout layer exists
for l = 1:size(layers,1)
    if contains(layers(l).Name,'drop')
        fprintf(fileID, strcat( ... 
            '\r\nDropout at layer: ', num2str(l), ...
            '\r\nDropout probability: ', num2str(hp.dropoutProb),'\r'));              
    else
        continue
    end
end
fclose(fileID);

end
