%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief This function saves results from training the network
%
% @param[in] net                - Trained neural network
% @param[in] trainingInfo       - struct containing network info from training

% @param[in] hyperparameters    - Struct containing hyperparameters
% @param[in] savePath           - Path location
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function saveTrainingResults(net, trainingInfo, hp, savePath)
    Output.INFO(['Saving network results to ', savePath,'\n']);
    
    layers = net.Layers;
    
    saveHyperparameters(savePath, hp, layers);
    plotLoss(trainingInfo, savePath)                                           % Loss   
    plotAccuracy(trainingInfo, savePath)                                       % Accuracy
    
    % Plot filters 
    numFilterIterations = hp.numFilterIterations;    
    for l = 1:size(layers,1)
        if contains(layers(l).Name,'Conv')
            plotFilters(net, l, 1:16, [4 4], numFilterIterations, savePath)
        else
            continue
        end
    end
    %Plot fully connected layers
%     numFCiterations = hyperparameters.numFCiterations;    
%     plotFullyConnectedLayer(net,23,1:16, numFCiterations, savePath);        % fc1
%     plotFullyConnectedLayer(net,26,1:2, numFCiterations, savePath);         % fc2

end

