% @brief Set the training options for the neural network 
%
% param[in] hp          - hyperparameters struct
% param[in] X_Train     - Training data
% param[in] X_Val       - Validation data
% param[in] T_Val       - Validation data labels
% param[out] options    - Validation data labels
function options = setTrainingOptions(hp, X_Train, X_Val, T_Val)

    numValidationsPerEpoch = 2;
    validationFrequency = floor(size(X_Train,4)/hp.miniBatchSize/numValidationsPerEpoch);

    options = trainingOptions('sgdm',...
        'InitialLearnRate', hp.initLearnRate, ...       
        'LearnRateSchedule','piecewise',...
        'LearnRateDropFactor',hp.learnRateDropFactor,...
        'LearnRateDropPeriod',hp.learnRateDropPeriod,...        
        'Momentum', hp.momentum, ...  
        'L2Regularization', hp.L2regularization, ...      
        'VerboseFrequency',validationFrequency,...                
        'ValidationData',{X_Val,T_Val},...
        'ValidationFrequency',validationFrequency,...
        'ValidationPatience',Inf,...
        'shuffle', hp.shuffle,...
        'Plots','training-progress',...            
        'MiniBatchSize', hp.miniBatchSize, ...
        'MaxEpochs', hp.maxEpochs);
end
