% @brief Initializes weights of conv and fc layers
%
% param[in] layers      - [numLayers,1] vector
% param[in] hp          - hyperparameters struct
% param[out] layers     - layers with weights initialized

function layers = setWeights(layers,hp)
    % Convolutional layers    
    convCounter = 0;
    for l = 1:size(layers,1)
        if contains(layers(l).Name,'Conv')    
            k = layers(l).FilterSize(1);
            c = layers(l).NumChannels;
            n = (k^2)*c;
            stdev = sqrt(2/n);
            layers(l).Weights = randn([hp.filterSize hp.filterSize layers(l).NumChannels layers(l).NumFilters]) * stdev;
            convCounter = convCounter + 1;
        else
            continue
        end
    end
    
    fcCounter = 0;
    fc1_inputSize =  2^(convCounter-1)*hp.numFilters*hp.filterSize^2;
    % Fully connected layers
    for l = 1:size(layers,1)
        if contains(layers(l).Name,'Feedforward1')
            n = fc1_inputSize + layers(l).OutputSize;
            stdev = sqrt(2/n);
            imSize = hp.imageInputSize(1)/2^(convCounter);
            layers(l).Weights = randn([layers(l).OutputSize imSize*imSize*hp.numFilters*2^(convCounter-1)]) * stdev;
            fc1Idx  = l;
            fcCounter = fcCounter + 1;
            break;
        else
            continue
        end
    end
    
    fc2_inputSize = layers(fc1Idx).OutputSize;
    for l = 1:size(layers,1)
        if contains(layers(l).Name,'Feedforward2')
            n = fc2_inputSize + layers(l).OutputSize;
            stdev = sqrt(2/n);
            layers(l).Weights = randn([layers(l).OutputSize hp.fcHiddenSize(1)]) * stdev;
            fcCounter = fcCounter + 1;           
            break;
        else
            continue
        end
    end        
    % Output layer (must be set manually)
    outLayer_inputSize = hp.fcHiddenSize(fcCounter);
    n = outLayer_inputSize + hp.fcOutputSize;
    stdev = sqrt(2/n);
    layers(size(layers,1)-2).Weights = randn([hp.fcOutputSize hp.fcHiddenSize(fcCounter)]) *stdev;
end

