%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief Plot accuracy vs training iterations
%
% @param[in] trainingInfo   - struct containing network info from training
% @param[in] savePath       - Path location
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function  plotAccuracy(trainingInfo, savePath)
    Output.INFO('Plotting accuracy.\n');
    accFig = figure(301);

    iterations = 1:size(trainingInfo.TrainingLoss,2);
    [~,trainAcc, ~, valAcc] = getLossAndAccuracy(trainingInfo, iterations);
    

%% plot accuracy
    plot(iterations,trainAcc, 'b', iterations , valAcc, 'r', 'LineWidth', 3); 
    title('Training and Validation Accuracy');
    xlabel('Iterations'); ylabel('Accuracy');
    legend('Training accuracy', 'Validation accuracy', 'Location', 'southeast');
    % Adjust axis properties
    set(gca                                 , ...
        'FontName'          , 'Helvetica'   , ...
        'FontSize'          , 40            , ...
        'LineWidth'         , 3             , ...
        'YGrid'             , 'on'          );    
    %% Adjust figure properties
    x0 = 10;
    y0 = 10;
    width = 1900;
    height = 1100;    
    set(gcf                                         , ...
        'Position'          , [x0,y0,width,height]  , ...
        'PaperPositionMode' , 'auto'                );
    %% Save figure
    name = 'Accuracy';
    formattype = 'epsc';
    filename = fullfile(savePath,name);
    saveas(accFig,filename,formattype);
    
    close(accFig);
end

