% @brief Plot filters of a convolutional layer  
%
% param[in] net                 - trained network
% param[in] layer               - Index of convolutional layer [integer]
% param[in] channels            - which filters to plot
% param[in] size                - dimension size of output plot
% param[in] numFilterIterations - Number of pyramid level iterations 
% param[in] savePath            - Path location
function plotFilters(net, layer, channels, size, numFilterIterations , savePath)
    plotTime = tic;
    filterFig = figure(400);
    name = net.Layers(layer).Name;    
    Output.INFO(['Plotting filters from layer: ', name,'.\n']);

    I = deepDreamImage(net,layer, channels, ... 
        'PyramidLevels',numFilterIterations, ...
        'ExecutionEnvironment', 'cpu', ...
        'Verbose',0);
    montage(I, 'Size', size)
%     title(['Layer ',name,' Features']) 
    %% Adjust figure properties
    set(gca                                 , ...
        'FontName'          , 'Helvetica'   , ...
        'FontSize'          , 40            );
    x0 = 10;
    y0 = 10;
    width = 1900;
    height = 1100;
    set(gcf                                         , ...
        'Position'          , [x0,y0,width,height]  , ...            
        'PaperPositionMode' , 'auto'                );
    %% Save figure
    formattype = 'epsc';
    filename = fullfile(savePath,name);
    saveas(filterFig,filename,formattype);
    
    close(filterFig);
    Output.INFO(['Filter plotted in time: ', num2str(toc(plotTime)),'s\n']);    
end



