% @brief Plots input image
%
% param[in] microDoppler - [nfft,numFrames] matrix
% param[in] idx          - index of input images
% param[in] outputFolder 
% param[in] prf          - Pulse Repetition Frequency 

function figMD = plotInputImage(microDoppler, idx, prf, window, dB_limit)
    Output.INFO(['Plotting input image ', num2str(idx),'\n']);

    [M,numFrames,~,~] = size(microDoppler);
    dopplerAx = linspace(-prf/2,prf/2,M);
    timeAx = linspace(0,(1/prf)*window,numFrames);

    figName = 'Micro Doppler';
    figMD = figure('Name',figName);    
    
    microDoppler = max(microDoppler(:,:,:,idx),0);     % Remove negative numbers that may appear from interpolation when using imresize    
    microDoppler_dB = 10*log10(microDoppler);
    microDoppler_dB_limited = max(microDoppler_dB, dB_limit);
    
    surf(timeAx,dopplerAx,(microDoppler_dB_limited),'LineStyle','none');
    title('Time-frequency power spectrum'); 
    xlabel('Time [s]'); 
    ylabel('Doppler frequency [Hz]');
    colormap('jet');

    cc = colorbar;
    ylabel(cc, 'Power [dB]');
    colorLim = [-45 0];
    caxis(colorLim);
    set(gca                                 , ...
        'FontName'          , 'Helvetica'   , ...
        'FontSize'          , 40            , ...
        'LineWidth'         , 3             , ...
        'YGrid'             , 'on'          );
    
    view(2);
end


