%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief Plot loss vs training iterations
%
% @param[in] trainingInfo   - struct containing network info from training
% @param[in] savePath       - Path location
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function  plotLoss(trainingInfo, savePath)
    Output.INFO('Plotting loss.\n');
    lossFig = figure(300);

    iterations = 1:size(trainingInfo.TrainingLoss,2);
    [trainLoss, ~, valLoss, ~] = getLossAndAccuracy(trainingInfo, iterations);
    
    %% plot loss
    plot(iterations, trainLoss,'b', iterations,valLoss,'r', 'LineWidth', 3);
    title('Training and Validation Loss');
    xlabel('Iterations'); ylabel('Loss');
    legend('Training loss', 'Validation loss', 'Location', 'northeast');
    % Adjust axis properties
    set(gca                                 , ...
        'FontName'          , 'Helvetica'   , ...
        'FontSize'          , 40            , ...
        'LineWidth'         , 3             , ...
        'YGrid'             , 'on'          );

    %% Adjust figure properties
    x0 = 10;
    y0 = 10;
    width = 1900;
    height = 1100;    
    set(gcf                                         , ...
        'Position'          , [x0,y0,width,height]  , ...
        'PaperPositionMode' , 'auto'                );
    %% Save figure
    name = 'Loss';
    formattype = 'epsc';
    filename = fullfile(savePath,name);
    saveas(lossFig,filename,formattype);
    
    close(lossFig);
end

