clc; clear; close all;
addpath(genpath('..\..\RadarClassification'));

datasetsSettings;

Output.INFO('Getting trainingdata\n');
%% Get training images
[X_Train_Dog, T_Train_Dog] = initInputdata(dogTrainingPath, 'dog', dataParameters.windowSizeSynthetic, dataParameters.overlap);
[X_Train_Human, T_Train_Human] = initInputdata(humanTrainingPath, 'human', dataParameters.windowSizeSynthetic, dataParameters.overlap);
% Balance datasets
[X_Train_Dog, X_Train_Human, T_Train_Dog, T_Train_Human] = balanceDatasets(X_Train_Dog, X_Train_Human, T_Train_Dog, T_Train_Human);
% Merge human and dog data
X_Train = cat(4,X_Train_Dog,X_Train_Human);
T_Train = cat(2,T_Train_Dog,T_Train_Human);

%% Get synthetic test images 
Output.INFO('Getting synthetic testdata\n');
[X_Test_Dog, T_Test_Dog] = initInputdata(dogTestPathSynthetic, 'dog', dataParameters.windowSizeSynthetic, dataParameters.overlap);
[X_Test_Human, T_Test_Human] = initInputdata(humanTestPathSynthetic, 'human', dataParameters.windowSizeSynthetic, dataParameters.overlap);
% Balance datasets
[X_Test_Dog, X_Test_Human, T_Test_Dog, T_Test_Human] = balanceDatasets(X_Test_Dog, X_Test_Human, T_Test_Dog, T_Test_Human);
% Merge human and dog data
X_Test_Synthetic = cat(4,X_Test_Dog,X_Test_Human);
T_Test_Synthetic = cat(2,T_Test_Dog,T_Test_Human);

%% Get real test images
Output.INFO('Getting real testdata\n');
[X_Test_Dog, T_Test_Dog] = initInputdata(dogTestPathReal, 'dog', dataParameters.windowSizeReal, dataParameters.overlap);
[X_Test_Human, T_Test_Human] = initInputdata(humanTestPathReal, 'human', dataParameters.windowSizeReal, dataParameters.overlap);
% Balance datasets
[X_Test_Dog, X_Test_Human, T_Test_Dog, T_Test_Human] = balanceDatasets(X_Test_Dog, X_Test_Human, T_Test_Dog, T_Test_Human);
% Merge human and dog data
X_Test_Real = cat(4,X_Test_Dog,X_Test_Human);
T_Test_Real = cat(2,T_Test_Dog,T_Test_Human);

%% Resize data
Output.INFO('Resizing data\n');
% Resize images
X_Train = imresize(X_Train, dataParameters.imSize);
X_Test_Synthetic = imresize(X_Test_Synthetic, dataParameters.imSize);
X_Test_Real = imresize(X_Test_Real, dataParameters.imSize);

%% Save data 
Output.INFO('Saving data\n');

save([datafolder,'X_Train.mat'],'X_Train','-v7.3');    
save([datafolder,'T_Train.mat'],'T_Train','-v7.3');    

save([datafolder,'X_Test_Synthetic.mat'],'X_Test_Synthetic','-v7.3');    
save([datafolder,'T_Test_Synthetic.mat'],'T_Test_Synthetic','-v7.3');

save([datafolder,'X_Test_Real.mat'],'X_Test_Real','-v7.3');    
save([datafolder,'T_Test_Real.mat'],'T_Test_Real','-v7.3');

Output.INFO('Script ended.\n');
