%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% @brief Split and stack micro doppler matrices into input images   
% @param[in] path           - Path to directory with micro doppler matrices
% @param[in] label          - Name of class to be labeled
% @param[in] dataParameters - Parameters defining data 
% @param[out] X             - Input data
% @param[out] T             - Labels
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [X, T] = initInputdata(path, label, windowSize, overlap)
    files = dir(path);    
    files(1:2) = [];
    if ~cellfun('isempty', {files})
        % Split micro doppler matrices
        X = [];
        for file = 1:size(files,1)
            md2D = load(strcat(path,files(file).name));
            md4D = splitMicroDoppler(md2D.microDoppler,windowSize,overlap);
            X = cat(4, X, md4D);
        end
        %Label data
        T = categorical(NaN(1,size(X,4)));
        T(:) = categorical({label});
    else
        X = [];
        T = [];
    end
    
end